@@ -1,3 +1,22 @@
+# Copyright (c) 2022-2023 The pymovements Project Authors
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 """
 This module holds the implementation for the Engbert microsaccades algorithm.
 """
@@ -6,8 +25,8 @@ from __future__ import annotations
 from collections.abc import Sized
 
 import numpy as np
+import polars as pl
 
-from pymovements.events import Saccade
 from pymovements.transforms import consecutive
 
 
@@ -15,9 +34,9 @@ def microsaccades(
     velocities: np.ndarray,
     threshold: np.ndarray | tuple[float] | str = 'engbert2015',
     threshold_factor: float = 6,
-    min_duration: int = 6,
-    min_threshold: float = 1e-10,
-) -> list[Saccade]:
+    minimum_duration: int = 6,
+    minimum_threshold: float = 1e-10,
+) -> pl.DataFrame:
     """Detect micro-saccades from velocity gaze sequence.
 
     This algorithm has a noise-adaptive velocity threshold parameter, which can also be set
@@ -37,16 +56,16 @@ def microsaccades(
         a reference of valid methods. Default: `engbert2015`
     threshold_factor : float
         factor for relative velocity threshold computation. Default: 6
-    min_duration : int
+    minimum_duration : int
         minimal saccade duration in samples. Default: 6
-    min_threshold : float
+    minimum_threshold : float
         minimal threshold value. Raises ValueError if calculated threshold is too low.
         Default: 1e-10
 
     Returns
     -------
-    list[Saccade]
-        List of Saccades
+    pl.DataFrame
+        A dataframe with detected saccades as rows.
 
     Raises
     ------
@@ -61,10 +80,10 @@ def microsaccades(
             raise ValueError('threshold must be either string or two-dimensional')
         threshold = np.array(threshold)
 
-    if (threshold < min_threshold).any():
+    if (threshold < minimum_threshold).any():
         raise ValueError(
             'threshold does not provide enough variance as required by min_threshold'
-            f' ({threshold} < {min_threshold})',
+            f' ({threshold} < {minimum_threshold})',
         )
 
     # Radius of elliptic threshold.
@@ -80,18 +99,23 @@ def microsaccades(
     candidates = consecutive(arr=outside_ellipse_indices)
 
     # Filter all candidates by minimum duration.
-    candidates = [candidate for candidate in candidates if len(candidate) >= min_duration]
+    candidates = [candidate for candidate in candidates if len(candidate) >= minimum_duration]
 
-    # Create saccades from valid candidates.
-    saccades = []
-    for saccade_indices in candidates:
-        saccade = Saccade(
-            onset=saccade_indices[0],
-            offset=saccade_indices[-1],
-        )
-        saccades.append(saccade)
+    # Create saccades from valid candidates. First channel is onset, second channel is offset.
+    saccades = np.array([
+        (candidate_indices[0], candidate_indices[-1])
+        for candidate_indices in candidates
+    ])
 
-    return saccades
+    # Create event dataframe from saccade onset and offsets.
+    event_df = pl.from_dict(
+        {
+            'type': 'saccade',
+            'onset': saccades[:, 0].tolist(),
+            'offset': saccades[:, 1].tolist(),
+        },
+    )
+    return event_df
 
 
 def compute_threshold(arr: np.ndarray, method: str = 'engbert2015') -> np.ndarray:
